﻿using System;
using System.Windows.Forms;
using System.Collections.Generic;
using System.ServiceModel.Description;
using System.Diagnostics;
using System.Text;
//using Framework.Common.Classes.Exceptions;
//using Framework.Common.Classes.Logging;
using GeoBrowser.GeoLookup;

/**************************************************************************************************
**************************************  GeoServiceProxy.cs ****************************************
***************************************************************************************************
 
      PROJECT:  Framework.eSketch.Presentation.Windows.e-Sketch
         FILE:  GeoServiceProxy.cs
      PURPOSE:  
  
       AUTHOR:  greg.block

   This program is proprietary to CertusView Technologies, LLC. and is not to be reproduced, used, or 
   disclosed without permission. 

***************************************************************************************************
*************************** Copyright © 2009, CertusView Technologies, LLC. ***********************
**************************************************************************************************/
namespace GeoBrowser.Classes
{
    internal static class GeoServiceProxy
    {

        /// <summary>
        /// Retrieves imagery from the geo service
        /// </summary>
        /// <param name="userCredentials"></param>
        /// <param name="extentInfo"></param>
        /// <param name="imageTheme"></param>
        /// <param name="serviceLevel"></param>
        /// <returns></returns>
        internal static ImageInfo GetImage(ExtentInfo extentInfo, ImageTheme imageTheme, ServiceLevel serviceLevel)
        {
            try
            {
                using (GeoLookup.GeoLookup lookupServiceClient = CreateLookupServiceClient())
                {
                    Stopwatch stopwatch = new Stopwatch();
                    stopwatch.Start();
                    ImageInfo imageInfo = lookupServiceClient.GetImage(extentInfo, imageTheme, serviceLevel);
                    stopwatch.Stop();
                    return imageInfo;
                }
            }
            catch(Exception ex)
            {
                System.Diagnostics.Debug.WriteLine(ex.Message);
                throw;
            }
        }


        private static GeoLookup.GeoLookup CreateLookupServiceClient()
        {
            UserIdentity userIdentity = new UserIdentity();
            userIdentity.UserName = "VWL.User";
            GeoLookup.GeoLookup lookupServiceClient = new GeoLookup.GeoLookup();
            lookupServiceClient.UserIdentityValue = userIdentity;
            return lookupServiceClient;
        }

    }
}
