﻿#region " Copyright Information... "
/**************************************************************************************************
***************************************************************************************************
 
  
       AUTHOR:  greg.block

   This program is proprietary to CertusView Technologies, LLC. and is not to be reproduced, used, or 
   disclosed without permission. 

***************************************************************************************************
*************************** Copyright © 2009, CertusView Technologies, LLC. ***********************
**************************************************************************************************/
#endregion

using System;
using System.Configuration;
using System.IO;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace GeoBrowser
{
    public partial class Default : System.Web.UI.Page
    {
        #region "Constant declarations..."
        private const string SOURCE_URL_KEY = "SourceUrl";
        private const string IMAGE_SIZE_KEY = "ImageSize";
        private const string DEFAULT_LAT_KEY = "Latitude";
        private const string DEFAULT_LON_KEY = "Longitude";
        #endregion

        #region "Properties..."
        private static string DefaultLatitude
        {
            get
            {
                return ConfigurationManager.AppSettings[DEFAULT_LAT_KEY];
            }
        }

        private static string DefaultLongitude
        {
            get
            {
                return ConfigurationManager.AppSettings[DEFAULT_LON_KEY];
            }
        }
        private static string SourceUrl
        {
            get
            {
                return ConfigurationManager.AppSettings[SOURCE_URL_KEY];
            }
        }

        private static int ImageSize
        {
            get
            {
                return Convert.ToInt32(ConfigurationManager.AppSettings[IMAGE_SIZE_KEY]);
            }
        }

        internal static string ImageFolder
        {
            get
            {
                string imageFolder = Path.Combine(Path.GetTempPath(), "RasterCache");
                if (!Directory.Exists(imageFolder))
                {
                    Directory.CreateDirectory(imageFolder);
                }
                return imageFolder;
            }
        }
        #endregion

        #region "Events..."
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                if (String.IsNullOrEmpty(Request.QueryString["x"]))
                {
                    if (String.IsNullOrEmpty(LatitudeTextBox.Text)) LatitudeTextBox.Text = DefaultLatitude;
                    if (String.IsNullOrEmpty(LongitudeTextBox.Text)) LongitudeTextBox.Text = DefaultLongitude;
                }
                else
                {
                    LongitudeTextBox.Text = Request.QueryString["x"];
                    LatitudeTextBox.Text = Request.QueryString["y"];
                }
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.StandardColors.White);
                Map1.RestrictedExtent= new RectangleShape(-131.22, 55.05, -54.03, 16.91);

                Map1.MapUnit = GeographyUnit.DecimalDegree;
                Map1.MapTools.MouseCoordinate.Enabled = true;
                Map1.MapTools.MouseCoordinate.MouseCoordinateType = MouseCoordinateType.LongitudeLatitude;
                Map1.MapTools.MouseMapTool.Enabled = true;
                Map1.MapTools.ScaleLine.Enabled = true;
                Map1.MapTools.OverlaySwitcher.Enabled = true;
                Map1.ClientZoomLevelScales.Add(563);
                Map1.ClientZoomLevelScales.Add(281.5);

                CreateHybridOverlay();
                CreateRoadsOverlay();
 
                Map1.ZoomTo(new PointShape(Double.Parse(LongitudeTextBox.Text), Double.Parse(LatitudeTextBox.Text)), 1000);

            }
        }

        protected void CenterButton_Click(object sender, EventArgs e)
        {
            double x = Double.Parse(LongitudeTextBox.Text);
            double y = Double.Parse(LatitudeTextBox.Text);
            Map1.CenterAt(x, y);
            Map1.ZoomTo(new PointShape(x, y), 1000);
        }

        protected void AerialButton_Click(object sender, EventArgs e)
        {
            Response.Redirect(String.Format("DrawMap.aspx?ulx={0}&uly={1}&lrx={2}&lry={3}", 
                Map1.CurrentExtent.UpperLeftPoint.X, Map1.CurrentExtent.UpperLeftPoint.Y,
                Map1.CurrentExtent.LowerRightPoint.X, Map1.CurrentExtent.LowerRightPoint.Y));
        }
        #endregion

        #region "Private methods..."

        private void CreateOverlay(string overlayName, string serviceLevelSetting, string styleSetting,
            bool isTiled)
        {
            WmsOverlay wmsOverlay = new WmsOverlay(overlayName);
            wmsOverlay.ServerUris.Add(new Uri(SourceUrl));
            wmsOverlay.Parameters.Add("STYLES", "STYLES");
            wmsOverlay.Parameters.Add("SERVICE_LEVEL", serviceLevelSetting);
            wmsOverlay.Parameters.Add("LAYERS", styleSetting);
            wmsOverlay.Parameters.Add("CRS", "EPSG:4326");
            wmsOverlay.TileType = TileType.MultipleTile;
            wmsOverlay.TileHeight = wmsOverlay.TileWidth = 256;
            wmsOverlay.TransitionEffect = TransitionEffect.Stretching;
            Map1.CustomOverlays.Add(wmsOverlay);
        }

        private void CreateRoadsOverlay()
        {
            CreateOverlay("Roads", "Standard", "Roads", true);
        }

        private void CreateHybridOverlay()
        {
            CreateOverlay("Hybrid", "Standard", "Hybrid", true);
        }

        #endregion
    }
}
