﻿#region " Copyright Information... "
/**************************************************************************************************
***************************************************************************************************
 
  
       AUTHOR:  greg.block

   This program is proprietary to CertusView Technologies, LLC. and is not to be reproduced, used, or 
   disclosed without permission. 

***************************************************************************************************
*************************** Copyright © 2009, CertusView Technologies, LLC. ***********************
**************************************************************************************************/
#endregion

using System;
using System.Drawing;
using System.IO;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace GeoBrowser
{
    public partial class DrawMap : System.Web.UI.Page
    {
        #region "Properties..."
        internal static string ImageFolder
        {
            get
            {
                string imageFolder = Path.Combine(Path.GetTempPath(), "GetBitmap");
                if (!Directory.Exists(imageFolder))
                {
                    Directory.CreateDirectory(imageFolder);
                }
                return imageFolder;
            }
        }
        #endregion

        #region "Events..."
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.StandardColors.White);
                Map1.RestrictedExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);

                Map1.MapUnit = GeographyUnit.DecimalDegree;
                Map1.MapTools.MouseCoordinate.Enabled = true;
                Map1.MapTools.MouseCoordinate.MouseCoordinateType = MouseCoordinateType.LongitudeLatitude;
                Map1.MapTools.MouseMapTool.Enabled = true;
                Map1.MapTools.ScaleLine.Enabled = false;
                Map1.ClientZoomLevelScales.Add(563);
                Map1.ClientZoomLevelScales.Add(281.5);

                InMemoryFeatureLayer shapeLayer = CreateInMemoryLayer();

                Map1.DynamicOverlay.Layers.Add("shapeLayer", shapeLayer);

                if (!String.IsNullOrEmpty(Request.QueryString["ulx"]))
                {
                    RectangleShape rectangleShape = CreateRasterLayer();
                    Map1.ZoomTo(rectangleShape.GetCenterPoint(), 281.5);
                }

            }
        }

        protected void buttonSubmit_Click(object sender, ImageClickEventArgs e)
        {
            InMemoryFeatureLayer shapeLayer = (InMemoryFeatureLayer)Map1.DynamicOverlay.Layers["shapeLayer"];
            foreach (Feature feature in Map1.EditOverlay.Features)
            {
                if (!shapeLayer.InternalFeatures.Contains(feature.Id))
                {
                    shapeLayer.InternalFeatures.Add(feature.Id, feature);
                }
            }

            Map1.EditOverlay.Features.Clear();
            Map1.EditOverlay.TrackMode = TrackMode.None;
            Map1.DynamicOverlay.Redraw();

            Bitmap bitmap = Map1.GetBitmap();
            bitmap.Save(Path.Combine(@"C:\ImageCacheFolder", String.Format("ToddSubmit-{0}.jpg", Guid.NewGuid().ToString())));
        }

        protected void buttonEditShape_Click(object sender, ImageClickEventArgs e)
        {
            InMemoryFeatureLayer shapeLayer = (InMemoryFeatureLayer)Map1.DynamicOverlay.Layers["shapeLayer"]; ;
            foreach (Feature feature in shapeLayer.InternalFeatures)
            {
                Map1.EditOverlay.Features.Add(feature.Id, feature);
            }

            shapeLayer.InternalFeatures.Clear();
            Map1.EditOverlay.TrackMode = TrackMode.Edit;
            Map1.DynamicOverlay.Redraw();
        }
        protected void Map1_ExtentChanged(object sender, ExtentChangedEventArgs e)
        {
            RectangleShape rectangleShape = CreateRasterLayer(e.CurrentExtent);
            Map1.ZoomTo(rectangleShape.GetCenterPoint(), 563);
        }

        protected void HybridButton_Click(object sender, EventArgs e)
        {
            PointShape pointShape = Map1.CurrentExtent.GetCenterPoint();
            Response.Redirect(String.Format("default.aspx?x={0}&y={1}", pointShape.X, pointShape.Y));
        }

        #endregion

        #region "Private methods..."
        private static InMemoryFeatureLayer CreateInMemoryLayer()
        {
            InMemoryFeatureLayer shapeLayer = new InMemoryFeatureLayer();
            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.FromArgb(180, 102, 255, 102), 10, GeoColor.StandardColors.DarkGreen, 1);
            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Green, 4, true);
            shapeLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(180, 102, 255, 102), GeoColor.StandardColors.DarkGreen, 1);
            shapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            shapeLayer.DrawingQuality = DrawingQuality.HighQuality;
            return shapeLayer;
        }

        private RectangleShape CreateRasterLayer()
        {
            double ulx = Convert.ToDouble(Request.QueryString["ulx"]);
            double uly = Convert.ToDouble(Request.QueryString["uly"]);
            double lrx = Convert.ToDouble(Request.QueryString["lrx"]);
            double lry = Convert.ToDouble(Request.QueryString["lry"]);
            RectangleShape rectangleShape = new RectangleShape(new PointShape(ulx, uly), new PointShape(lrx, lry));

            return CreateRasterLayer(rectangleShape);
        }

        private RectangleShape CreateRasterLayer(RectangleShape rectangleShape)
        {
            string imageFile = Classes.GeoLookupHelper.GetImage(rectangleShape);

            GdiPlusRasterLayer gdiPlusImageLayer = new GdiPlusRasterLayer(imageFile);
            gdiPlusImageLayer.UpperThreshold = double.MaxValue;
            gdiPlusImageLayer.LowerThreshold = 0;

            Map1.StaticOverlay.Layers.Add(gdiPlusImageLayer);
            return rectangleShape;
        }

        #endregion

    }
}
